@@ -1,21 +1,9 @@
-//
-// Copyright (C) 2016~2016 by CSSlayer
-// wengxt@gmail.com
-//
-// This library is free software; you can redistribute it and/or modify
-// it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 2.1 of the
-// License, or (at your option) any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-// Lesser General Public License for more details.
-//
-// You should have received a copy of the GNU Lesser General Public
-// License along with this library; see the file COPYING. If not,
-// see <http://www.gnu.org/licenses/>.
-//
+/*
+ * SPDX-FileCopyrightText: 2016-2016 CSSlayer <wengxt@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ *
+ */
 #ifndef _FCITX_CANDIDATELIST_H_
 #define _FCITX_CANDIDATELIST_H_
 
@@ -137,6 +125,13 @@ public:
     }
 };
 
+class FCITXCORE_EXPORT DisplayOnlyCandidateWord : public CandidateWord {
+public:
+    DisplayOnlyCandidateWord(Text text) : CandidateWord(std::move(text)) {}
+
+    void select(InputContext *) const override {}
+};
+
 class DisplayOnlyCandidateListPrivate;
 
 class FCITXCORE_EXPORT DisplayOnlyCandidateList : public CandidateList {
@@ -144,7 +139,7 @@ public:
     DisplayOnlyCandidateList();
     ~DisplayOnlyCandidateList();
 
-    void setContent(std::vector<std::string> content);
+    void setContent(const std::vector<std::string> &content);
     void setContent(std::vector<Text> content);
     void setLayoutHint(CandidateLayoutHint hint);
     void setCursorIndex(int index);
@@ -163,7 +158,7 @@ private:
 
 class CommonCandidateListPrivate;
 
-enum CursorPositionAfterPaging { SameAsLast, DonotChange, ResetToFirst };
+enum class CursorPositionAfterPaging { SameAsLast, DonotChange, ResetToFirst };
 
 class FCITXCORE_EXPORT CommonCandidateList : public CandidateList,
                                              public PageableCandidateList,
@@ -176,6 +171,7 @@ public:
     void clear();
     void setSelectionKey(const KeyList &keyList);
     void setPageSize(int size);
+    int pageSize() const;
     void setLayoutHint(CandidateLayoutHint hint);
     void setGlobalCursorIndex(int index);
 
